@@ -33,7 +33,7 @@ from .data_number import DataNumber,DataNumberLookup
 from .reporting_config import ReportingConfig
 from .utils import LoggingMessages, FireStoreBase, FSDocument
 from .app_configuration import AppConfiguration
-from .quick_storage import QuickStorage
+from .quick_storage import QuickStorage, DebugApplication
 
 # Sales Inventory
 from .supplier import Supplier
