@@ -73,6 +73,22 @@ class FirestoreChangeRec(object):
             return self.changeDataSummary['before']
         return self.changeDataSummary['after']
     
+    def value(self,getParsed=False):
+        return self.getDictInfo('value',getParsed)
+    
+    def oldValue(self,getParsed=False):
+        return self.getDictInfo('oldValue',getParsed)
+        
+    def getDictInfo(self,dataKey, getParsed=False):
+        key = dataKey
+        obj = self.event
+        if getParsed:
+            key = 'after' if key == 'value' else 'before'
+            obj = self.changeDatSummary
+        
+        return obj[key]
+        
+    
     def priorObject(self):
         if self.changeDataSummary['before'] is None:
             return {}
@@ -84,7 +100,13 @@ class FirestoreChangeRec(object):
         priorData = self.priorObject().get('data',{})
         if priorData is None:
             priorData = {}
-        return priorData 
+        return priorData
+    
+    def __getitem__(self,item):
+        return self.currentObject().get(item,None)
+    
+    def get(self,item,default=None,current=True):
+        return self.data(current=current).get(item,default)
     
     @property
     def path(self):
