@@ -1,6 +1,38 @@
 from .utils import FireStoreBase
 from datetime import datetime
 
+class DebugApplication(object):
+    
+    DEBUG_DOC_ID = 'DebuggingApplication'
+    
+    def __init__(self, applicationName):
+        self.appName = applicationName
+        self.quickStorage = QuickStorage.GetQuickStorage(DebugApplication.DEBUG_DOC_ID,application='all')
+        if self.quickStorage is None:
+            self.quickStorage = QuickStorage.quickSet(DebugApplication.DEBUG_DOC_ID,{"debug":{applicationName:False}})
+        
+        self.debugMap = self.quickStorage.qsValue.get('debug',{})
+        if self.debugMap.get(self.appName,None) is None:
+            self.setDebugOff()
+        
+    @property
+    def doDebug(self):
+        return self.debugMap.get(self.appName,False)
+    
+    def setDebugOn(self):
+        self.debugUpdate(True)
+    
+    def setDebugOff(self):
+        self.debugUpdate(False)
+    
+    def debugUpdate(self,onOffValue):
+        self.debugMap[self.appName] = onOffValue
+        QuickStorage.quickUpdate(DebugApplication.DEBUG_DOC_ID,f"debug.{self.appName}",onOffValue)
+    
+    @classmethod
+    def DoDebug(cls,applicationName):
+        return DebugApplication(applicationName).doDebug
+
 class QuickStorage(FireStoreBase):
     '''
     Found there are limitations to memcache... so we're creating a quickstorage... basically..
@@ -45,6 +77,10 @@ class QuickStorage(FireStoreBase):
         docDict['fs_docSnap'] = snap
         docDict['fs_docRef'] = ref
         return cls(cls.get_client(),**docDict)
+    
+    @classmethod
+    def GetQuickStorage(cls,inKey,application):
+        return cls.__get_qs(inKey,application)
 
     @classmethod
     def __get_qs(cls,inKey, application=None):
