@@ -1,13 +1,13 @@
 from .. reserve_summary import ReserveSummary
 from typing import Any
 from .. import GrowWeek
+from .. import FSDocument
 from .. import GrowMonth
 from .. import ItemMonth
 from .. import ItemMonthReserves
 from .. import ItemMonthSummary
 from .. import ItemReserve
 from .. import ItemMonthCollection
-from .. import DataNumberLookup
 from .. import InventoryActiveItems
 from .. import InventoryTracking
 from .. import QuickStorage
@@ -247,13 +247,21 @@ class SalesInventoryAPI(object):
         mi = QuickStorage.getValue('MonthlyInventoryItems')
         if mi is None or force:
             monthItems = InventoryTracking.getInstance().monthly_items
+            path = 'application_data/Color_Orchids/Customer_Tracking/StorageBlob/recipe_costing'
+            colRef = InventoryActiveItems.get_firestore_client().collection(path)
+            fsDocs = [FSDocument(x,loadData=True) for x in colRef.list_documents()]
             dictCreate = []
             dictCreate.append({'key_name':'image'})
             mi = []
             for monthItem in monthItems:
                 entry = {'item_type':monthItem, 'items_url':f'/rest/api/v1/recipe_items/{monthItem}','image':None}
-                items = InventoryActiveItems.get_active_recipe_items(monthItem,fldKey='data_number_lookup')
-                items = {k:v.get_custom_dict(dictCreate) for k,v in items.items()}
+                ##
+                ## Update -- 2/15/2022:  using get_active_recipe_items is stupid slow... and for our purposes... we can be quicker to filter 
+                ##                       to filter the responses... and not query Firestore 12 times
+                ##
+                #items = InventoryActiveItems.get_active_recipe_items(monthItem,fldKey='data_number_lookup')
+                items = {x.data['data_number_lookup']:{"image":x.data['image']} for x in fsDocs if x.data['item_type'] == monthItem and x.data['status'] == 'Active'}
+                #items = {k:v.get_custom_dict(dictCreate) for k,v in items.items()}
                 #images = jmespath.search("items.[*][] | [*].image[] | [*].image_url",items)
                 images = jmespath.search("*.image[] | [*].image_url",items)
                 if len(images) > 0:
