@@ -24,7 +24,7 @@ _default.default = JSONEncoder.default  # Save unmodified default.
 JSONEncoder.default = _default # Replace it.
 
 class FSDocument(object):
-    def __init__(self, fsDocument: object, loadSnap=True):
+    def __init__(self, fsDocument: object, loadSnap=True, loadData=False):
         self.snap = None
         self.ref = None
         self.origDoc = fsDocument
@@ -38,17 +38,30 @@ class FSDocument(object):
         elif isinstance(fsDocument,DocumentSnapshot):
             self.docType = 'snap'
             self.snap = fsDocument
+            loadSnap = True
             self.ref = fsDocument.reference
         elif isinstance(fsDocument,FSDocument):
             self.docType = 'fsDoc'
             self.snap = fsDocument.snap
             self.ref = fsDocument.ref
+        self._data = None
+        if loadSnap and loadData:
+            self._data = self.snap.to_dict()
 
     @classmethod
     def getInstance(cls,docPath, loadSnap=True):
         clt = FirestoreClient.getInstance().fsClient
         docRef = clt.document(docPath)
         return FSDocument(docRef,loadSnap)
+    
+    def __getitem__(self, item):
+        return self.data.get(item,None)
+    
+    @property
+    def data(self):
+        if self._data is None:
+            return {}
+        return self._data
 
     @property
     def exists(self):
@@ -1271,6 +1284,14 @@ def EnvironSetup(environment):
            'Development_Tracking':
               {'CO':'Color_Orchids',
                'NM': 'Customer_Tracking',
+               'AP': 'backend-firestore-test'},
+           'Production_Inventory': 
+              {'CO':'Color_Orchids',
+               'NM': 'Sales_Inventory',
+               'AP': 'colororchids-apps'},
+           'Development_Inventory':
+              {'CO':'Color_Orchids',
+               'NM': 'Sales_Inventory',
                'AP': 'backend-firestore-test'}}
     
     env_map = {'CO':'APP_FIRESTORE_COMPANY',
